@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,6 @@
 #ifndef DIRDEF_H
 #define DIRDEF_H
 
-#include "qtbc.h"
 #include "sortdict.h"
 #include "definition.h"
 
@@ -30,18 +29,18 @@ class QStrList;
 class FileDef;
 class OutputList;
 class UsedDir;
-class QTextStream;
+class FTextStream;
 
 class DirDef;
 
-/** A list of directories */
+/** A list of directories. */
 class DirList : public QList<DirDef>
 {
   public:
-   int compareItems(GCI item1,GCI item2);
+   int compareValues(const DirDef *item1,const DirDef *item2) const;
 };
 
-/** A directory */
+/** A model of a directory symbol. */
 class DirDef : public Definition
 {
   public:
@@ -49,12 +48,13 @@ class DirDef : public Definition
     virtual ~DirDef();
 
     // accessors
-    virtual DefType definitionType() const { return TypeDir; }
-    virtual QCString getOutputFileBase() const;
-    virtual bool isLinkableInProject() const;
-    virtual bool isLinkable() const;
-    QCString displayName() const { return m_dispName; }
-    QCString shortName() const { return m_shortName; }
+    DefType definitionType() const { return TypeDir; }
+    QCString getOutputFileBase() const;
+    QCString anchor() const { return QCString(); }
+    bool isLinkableInProject() const;
+    bool isLinkable() const;
+    QCString displayName(bool=TRUE) const { return m_dispName; }
+    const QCString &shortName() const { return m_shortName; }
     void addSubDir(DirDef *subdir);
     FileList *   getFiles() const        { return m_fileList; }
     void addFile(FileDef *fd);
@@ -62,20 +62,33 @@ class DirDef : public Definition
     bool isCluster() const { return m_subdirs.count()>0; }
     int level() const { return m_level; }
     DirDef *parent() const { return m_parent; }
+    int dirCount() const { return m_dirCount; }
     const QDict<UsedDir> *usedDirs() const { return m_usedDirs; }
     bool isParentOf(DirDef *dir) const;
     bool depGraphIsTrivial() const;
+    QCString shortTitle() const;
+    bool hasDetailedDescription() const;
 
     // generate output
-    void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
-    void writeDepGraph(QTextStream &t);
+    void writeDepGraph(FTextStream &t);
+    void writeTagFile(FTextStream &t);
 
     static DirDef *mergeDirectoryInTree(const QCString &path);
     bool visited;
+    void setDiskName(const QCString &name) { m_diskName = name; }
 
   private:
     friend void computeDirDependencies();
+
+    void writeDetailedDescription(OutputList &ol,const QCString &title);
+    void writeBriefDescription(OutputList &ol);
+    void writeDirectoryGraph(OutputList &ol);
+    void writeSubDirList(OutputList &ol);
+    void writeFileList(OutputList &ol);
+    void startMemberDeclarations(OutputList &ol);
+    void endMemberDeclarations(OutputList &ol);
+
     void setLevel();
     static DirDef *createNewDir(const char *path);
     static bool matchPath(const QCString &path,QStrList &l);
@@ -86,6 +99,7 @@ class DirDef : public Definition
     DirList m_subdirs;
     QCString m_dispName;
     QCString m_shortName;
+    QCString m_diskName;
     FileList *m_fileList;                 // list of files in the group
     int m_dirCount;
     int m_level;
@@ -93,6 +107,7 @@ class DirDef : public Definition
     QDict<UsedDir> *m_usedDirs;
 };
 
+/** Class representing a pair of FileDef objects */
 class FilePair 
 {
   public:
@@ -104,14 +119,16 @@ class FilePair
     FileDef *m_dst;
 };
 
+/** A sorted dictionary of FilePair objects. */
 class FilePairDict : public SDict<FilePair>
 {
   public:
     FilePairDict(int size) : SDict<FilePair>(size) {}
-    int compareItems(GCI item1,GCI item2);
+  private:
+    int compareValues(const FilePair *item1,const FilePair *item2) const;
 };
 
-/** Usage information of a directory . */
+/** Usage information of a directory. */
 class UsedDir
 {
   public:
@@ -129,7 +146,7 @@ class UsedDir
     bool m_inherited;
 };
 
-/** A usage relation between two direction. */
+/** A usage relation between two directories. */
 class DirRelation
 {
   public:
@@ -146,18 +163,19 @@ class DirRelation
     UsedDir *m_dst;
 };
 
-inline int DirList::compareItems(GCI item1,GCI item2)
+inline int DirList::compareValues(const DirDef *item1,const DirDef *item2) const
 {
-  return stricmp(((DirDef *)item1)->shortName(),((DirDef *)item2)->shortName());
+  return qstricmp(item1->shortName(),item2->shortName());
 }
 
+/** A sorted dictionary of DirDef objects. */
 class DirSDict : public SDict<DirDef>
 {
   public:
     DirSDict(int size) : SDict<DirDef>(size) {}
-    int compareItems(GCI item1,GCI item2)
+    int compareValues(const DirDef *item1,const DirDef *item2) const
     {
-      return stricmp(((DirDef *)item1)->shortName(),((DirDef *)item2)->shortName());
+      return qstricmp(item1->shortName(),item2->shortName());
     }
 };
 
