@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -1063,7 +1063,6 @@ void HtmlDocVisitor::visitPost(DocPara *p)
     }
   }
 
-  QCString context;
   // if the last element of a paragraph is something that should be outside of
   // the paragraph (<ul>,<dl>,<table>) then that will already have ended the 
   // paragraph and we don't need to do it here
@@ -2002,7 +2001,7 @@ void HtmlDocVisitor::writeMscFile(const QCString &fileName,
   }
   baseName.prepend("msc_");
   QCString outDir = Config_getString("HTML_OUTPUT");
-  QCString imgExt = Config_getEnum("DOT_IMAGE_FORMAT");
+  QCString imgExt = getDotImageExtension();
   MscOutputFormat mscFormat = MSC_BITMAP;
   if ("svg" == imgExt)
     mscFormat = MSC_SVG;
@@ -2046,7 +2045,7 @@ void HtmlDocVisitor::writePlantUMLFile(const QCString &fileName,
     baseName=baseName.left(i);
   }
   static QCString outDir = Config_getString("HTML_OUTPUT");
-  static QCString imgExt = Config_getEnum("DOT_IMAGE_FORMAT");
+  QCString imgExt = getDotImageExtension();
   if (imgExt=="svg")
   {
     generatePlantUMLOutput(fileName,outDir,PUML_SVG);
