@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -19,7 +19,9 @@
 #ifndef _PRINTDOCVISITOR_H
 #define _PRINTDOCVISITOR_H
 
+#include <qglobal.h>
 #include "docvisitor.h"
+#include "htmlentity.h"
 
 /*! Concrete visitor implementation for pretty printing */
 class PrintDocVisitor : public DocVisitor
@@ -55,106 +57,14 @@ class PrintDocVisitor : public DocVisitor
     void visit(DocSymbol *s)
     {
       indent_leaf();
-      switch(s->symbol())
+      const char *res = HtmlEntityMapper::instance()->utf8(s->symbol(),TRUE);
+      if (res)
       {
-	case DocSymbol::BSlash:  printf("\\"); break;
-	case DocSymbol::At:      printf("@"); break;
-	case DocSymbol::Less:    printf("<"); break;
-	case DocSymbol::Greater: printf(">"); break;
-	case DocSymbol::Amp:     printf("&"); break;
-	case DocSymbol::Dollar:  printf("$"); break;
-	case DocSymbol::Hash:    printf("#"); break;
-	case DocSymbol::Percent: printf("%%"); break;
-	case DocSymbol::Pipe:    printf("|"); break;
-	case DocSymbol::Copy:    printf("&copy;"); break;
-	case DocSymbol::Apos:    printf("'"); break;
-	case DocSymbol::Quot:    printf("\""); break;
-        case DocSymbol::Lsquo:   printf("&lsquo;"); break;
-        case DocSymbol::Rsquo:   printf("&rsquo;"); break;
-        case DocSymbol::Ldquo:   printf("&ldquo;"); break;
-        case DocSymbol::Rdquo:   printf("&rdquo;"); break;
-        case DocSymbol::Ndash:   printf("&ndash;"); break;
-        case DocSymbol::Mdash:   printf("&mdash;"); break;
-	case DocSymbol::Uml:     printf("&%cuml;",s->letter()); break;
-	case DocSymbol::Acute:   printf("&%cacute;",s->letter()); break;
-	case DocSymbol::Grave:   printf("&%cgrave;",s->letter()); break;
-	case DocSymbol::Circ:    printf("&%ccirc;",s->letter()); break;
-	case DocSymbol::Tilde:   printf("&%ctilde;",s->letter()); break;
-	case DocSymbol::Szlig:   printf("&szlig;"); break;
-	case DocSymbol::Cedil:   printf("&%ccedul;",s->letter()); break;
-	case DocSymbol::Ring:    printf("&%cring;",s->letter()); break;
-	case DocSymbol::Nbsp:    printf("&nbsp;"); break;
-	case DocSymbol::Aelig:   printf("&aelig;"); break;
-	case DocSymbol::AElig:   printf("&AElig;"); break;
-    case DocSymbol::GrkGamma:      printf("&Gamma;"); break;
-    case DocSymbol::GrkDelta:      printf("&Delta;"); break;
-    case DocSymbol::GrkTheta:      printf("&Theta;"); break;
-    case DocSymbol::GrkLambda:     printf("&Lambda;"); break;
-    case DocSymbol::GrkXi:         printf("&Xi;"); break;
-    case DocSymbol::GrkPi:         printf("&Pi;"); break;
-    case DocSymbol::GrkSigma:      printf("&Sigma;"); break;
-    case DocSymbol::GrkUpsilon:    printf("&Upsilon;"); break;
-    case DocSymbol::GrkPhi:        printf("&Phi;"); break;
-    case DocSymbol::GrkPsi:        printf("&Psi;"); break;
-    case DocSymbol::GrkOmega:      printf("&Omega;"); break;
-    case DocSymbol::Grkalpha:      printf("&alpha;"); break;
-    case DocSymbol::Grkbeta:       printf("&beta;"); break;
-    case DocSymbol::Grkgamma:      printf("&gamma;"); break;
-    case DocSymbol::Grkdelta:      printf("&delta;"); break;
-    case DocSymbol::Grkepsilon:    printf("&epsilon;"); break;
-    case DocSymbol::Grkzeta:       printf("&zeta;"); break;
-    case DocSymbol::Grketa:        printf("&eta;"); break;
-    case DocSymbol::Grktheta:      printf("&theta;"); break;
-    case DocSymbol::Grkiota:       printf("&iota;"); break;
-    case DocSymbol::Grkkappa:      printf("&kappa;"); break;
-    case DocSymbol::Grklambda:     printf("&lambda;"); break;
-    case DocSymbol::Grkmu:         printf("&mu;"); break;
-    case DocSymbol::Grknu:         printf("&nu;"); break;
-    case DocSymbol::Grkxi:         printf("&xi;"); break;
-    case DocSymbol::Grkpi:         printf("&pi;"); break;
-    case DocSymbol::Grkrho:        printf("&rho;"); break;
-    case DocSymbol::Grksigma:      printf("&sigma;"); break;
-    case DocSymbol::Grktau:        printf("&tau;"); break;
-    case DocSymbol::Grkupsilon:    printf("&upsilon;"); break;
-    case DocSymbol::Grkphi:        printf("&phi;"); break;
-    case DocSymbol::Grkchi:        printf("&chi;"); break;
-    case DocSymbol::Grkpsi:        printf("&psi;"); break;
-    case DocSymbol::Grkomega:      printf("&omega;"); break;
-    case DocSymbol::Grkvarsigma:   printf("&sigmaf;"); break;
-    case DocSymbol::Section:       printf("&sect;"); break;
-    case DocSymbol::Degree:        printf("&deg;"); break;
-    case DocSymbol::Prime:         printf("&prime;"); break;
-    case DocSymbol::DoublePrime:   printf("&Prime;"); break;
-    case DocSymbol::Infinity:      printf("&infin;"); break;
-    case DocSymbol::EmptySet:      printf("&empty;"); break;
-    case DocSymbol::PlusMinus:     printf("&plusmn;"); break;
-    case DocSymbol::Times:         printf("&times;"); break;
-    case DocSymbol::Minus:         printf("&minus;"); break;
-    case DocSymbol::CenterDot:     printf("&sdot;"); break;
-    case DocSymbol::Partial:       printf("&part;"); break;
-    case DocSymbol::Nabla:         printf("&nabla;"); break;
-    case DocSymbol::SquareRoot:    printf("&radic;"); break;
-    case DocSymbol::Perpendicular: printf("&perp;"); break;
-    case DocSymbol::Sum:           printf("&sum;"); break;
-    case DocSymbol::Integral:      printf("&int;"); break;
-    case DocSymbol::Product:       printf("&prod;"); break;
-    case DocSymbol::Similar:       printf("&sim;"); break;
-    case DocSymbol::Approx:        printf("&asymp;"); break;
-    case DocSymbol::NotEqual:      printf("&ne;"); break;
-    case DocSymbol::Equivalent:    printf("&equiv;"); break;
-    case DocSymbol::Proportional:  printf("&prop;"); break;
-    case DocSymbol::LessEqual:     printf("&le;"); break;
-    case DocSymbol::GreaterEqual:  printf("&ge;"); break;
-    case DocSymbol::LeftArrow:     printf("&larr;"); break;
-    case DocSymbol::RightArrow:    printf("&rarr;"); break;
-    case DocSymbol::SetIn:         printf("&isin;"); break;
-    case DocSymbol::SetNotIn:      printf("&notin;"); break;
-    case DocSymbol::LeftCeil:      printf("&lceil;"); break;
-    case DocSymbol::RightCeil:     printf("&rceil;"); break;
-    case DocSymbol::LeftFloor:     printf("&lfloor;"); break;
-    case DocSymbol::RightFloor:    printf("&rfloor;"); break;
-	default:
-	  printf("Error: unknown symbol found\n");
+        printf("%s",res);
+      }
+      else
+      {
+        printf("print: non supported HTML-entity found: %s\n",HtmlEntityMapper::instance()->html(s->symbol(),TRUE));
       }
     }
     void visit(DocURL *u)
@@ -178,35 +88,35 @@ class PrintDocVisitor : public DocVisitor
       switch (s->style())
       {
         case DocStyleChange::Bold:
-         if (s->enable()) printf("<bold>"); else printf("</bold>");
-         break;
+          if (s->enable()) printf("<bold>"); else printf("</bold>");
+          break;
         case DocStyleChange::Italic:
-         if (s->enable()) printf("<italic>"); else printf("</italic>");
-         break;
+          if (s->enable()) printf("<italic>"); else printf("</italic>");
+          break;
         case DocStyleChange::Code:
-         if (s->enable()) printf("<code>"); else printf("</code>");
-         break;
+          if (s->enable()) printf("<code>"); else printf("</code>");
+          break;
         case DocStyleChange::Subscript:
-         if (s->enable()) printf("<sub>"); else printf("</sub>");
-         break;
+          if (s->enable()) printf("<sub>"); else printf("</sub>");
+          break;
         case DocStyleChange::Superscript:
-         if (s->enable()) printf("<sup>"); else printf("</sup>");
-         break;
+          if (s->enable()) printf("<sup>"); else printf("</sup>");
+          break;
         case DocStyleChange::Center:
-         if (s->enable()) printf("<center>"); else printf("</center>");
-         break;
+          if (s->enable()) printf("<center>"); else printf("</center>");
+          break;
         case DocStyleChange::Small:
-         if (s->enable()) printf("<small>"); else printf("</small>");
-         break;
+          if (s->enable()) printf("<small>"); else printf("</small>");
+          break;
         case DocStyleChange::Preformatted:
-         if (s->enable()) printf("<pre>"); else printf("</pre>");
-         break;
+          if (s->enable()) printf("<pre>"); else printf("</pre>");
+          break;
         case DocStyleChange::Div:
-         if (s->enable()) printf("<div>"); else printf("</div>");
-         break;
+          if (s->enable()) printf("<div>"); else printf("</div>");
+          break;
         case DocStyleChange::Span:
-         if (s->enable()) printf("<span>"); else printf("</span>");
-         break;
+          if (s->enable()) printf("<span>"); else printf("</span>");
+          break;
       }
     }
     void visit(DocVerbatim *s)
@@ -221,8 +131,10 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::ManOnly: printf("<manonly>"); break;
         case DocVerbatim::LatexOnly: printf("<latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("<xmlonly>"); break;
+        case DocVerbatim::DocbookOnly: printf("<docbookonly>"); break;
         case DocVerbatim::Dot: printf("<dot>"); break;
         case DocVerbatim::Msc: printf("<msc>"); break;
+        case DocVerbatim::PlantUML: printf("<plantuml>"); break;
       }
       printf("%s",s->text().data());
       switch(s->type())
@@ -234,8 +146,10 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::ManOnly: printf("</manonly>"); break;
         case DocVerbatim::LatexOnly: printf("</latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("</xmlonly>"); break;
+        case DocVerbatim::DocbookOnly: printf("</docbookonly>"); break;
         case DocVerbatim::Dot: printf("</dot>"); break;
         case DocVerbatim::Msc: printf("</msc>"); break;
+        case DocVerbatim::PlantUML: printf("</plantuml>"); break;
       }
     }
     void visit(DocAnchor *a)
@@ -253,6 +167,7 @@ class PrintDocVisitor : public DocVisitor
         case DocInclude::IncWithLines: printf("incwithlines"); break;
         case DocInclude::DontInclude: printf("dontinclude"); break;
         case DocInclude::HtmlInclude: printf("htmlinclude"); break;
+        case DocInclude::LatexInclude: printf("latexinclude"); break;
         case DocInclude::VerbInclude: printf("verbinclude"); break;
         case DocInclude::Snippet: printf("snippet"); break;
       }
@@ -274,7 +189,7 @@ class PrintDocVisitor : public DocVisitor
     void visit(DocFormula *f)
     {
       indent_leaf();
-      printf("<formula name=%s test=%s/>",f->name().data(),f->text().data());
+      printf("<formula name=%s text=%s/>",f->name().data(),f->text().data());
     }
     void visit(DocIndexEntry *i)
     {
@@ -563,11 +478,12 @@ class PrintDocVisitor : public DocVisitor
       printf("<image src=\"%s\" type=\"",img->name().data());
       switch(img->type())
       {
-        case DocImage::Html: printf("html"); break;
-        case DocImage::Latex: printf("latex"); break;
-        case DocImage::Rtf: printf("rtf"); break;
+        case DocImage::Html:    printf("html"); break;
+        case DocImage::Latex:   printf("latex"); break;
+        case DocImage::Rtf:     printf("rtf"); break;
+        case DocImage::DocBook: printf("docbook"); break;
       }
-      printf("\" width=%s height=%s>\n",img->width().data(),img->height().data());
+      printf("\" %s %s>\n",img->width().data(),img->height().data());
     }
     void visitPost(DocImage *) 
     {
@@ -594,6 +510,16 @@ class PrintDocVisitor : public DocVisitor
       indent_post();
       printf("</mscfile>\n");
     }
+    void visitPre(DocDiaFile *df)
+    {
+      indent_pre();
+      printf("<diafile src=\"%s\">\n",df->name().data());
+    }
+    void visitPost(DocDiaFile *)
+    {
+      indent_post();
+      printf("</diafile>\n");
+    }
     void visitPre(DocLink *lnk)
     {
       indent_pre();
@@ -758,6 +684,16 @@ class PrintDocVisitor : public DocVisitor
       indent_post();
       printf("</vhdlflow>\n");
     }
+    void visitPre(DocParBlock *)
+    {
+      indent_pre();
+      printf("<parblock>\n");
+    }
+    void visitPost(DocParBlock *)
+    {
+      indent_post();
+      printf("</parblock>\n");
+    }
 
   private:
     // helper functions
