@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -17,6 +17,7 @@
 
 // Updates:
 // --------
+// 2013/05/14 - Updates for "new since 1.8.4".
 // 2012/08/02 - Updates for "new since 1.8.2".
 // 2012/04/18 - Updates for "new since 1.8.0".
 // 2011/07/28 - Updates for "new since 1.7.5".
@@ -42,12 +43,6 @@ class TranslatorSlovak : public Translator
     virtual QCString latexLanguageSupportCommand()
     { return "\\usepackage[slovak]{babel}\n"; }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-        return "utf-8";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -395,12 +390,6 @@ class TranslatorSlovak : public Translator
     virtual QCString trDefines()
     { return "Definícia makier"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *	list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Prototypy"; }
-
     /*! This is used in the documentation of a file as a header before the
      *	list of typedefs
      */
@@ -437,12 +426,6 @@ class TranslatorSlovak : public Translator
     virtual QCString trDefineDocumentation()
     { return "Dokumentácia k definíciám makier"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *	of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Dokumentácia prototypov"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *	of documentation blocks for typedefs
      */
@@ -493,13 +476,6 @@ class TranslatorSlovak : public Translator
       return result;
     }
 
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return " -- autor ";
-    }
-
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
     {
@@ -593,6 +569,7 @@ class TranslatorSlovak : public Translator
         case ClassDef::Protocol:   result+="protokol "; break;
         case ClassDef::Category:   result+="kategória "; break;
         case ClassDef::Exception:  result+="výnimky "; break;
+        default: break;
       }
       result+=clName;
       return result;
@@ -765,6 +742,7 @@ class TranslatorSlovak : public Translator
         case ClassDef::Protocol:   result+="protokol"; break;
         case ClassDef::Category:   result+="kategória"; break;
         case ClassDef::Exception:  result+="túto výnimku"; break;
+        default: break;
       }
       result+=" bola generovaná z ";
       if (single) result+="nasledujúceho súboru:";
@@ -772,12 +750,6 @@ class TranslatorSlovak : public Translator
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Register tried"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1032,7 +1004,7 @@ class TranslatorSlovak : public Translator
         "};\n"
         "\\endcode\n"
         "K vyššie uvedenému bude vygenerovaný nasledujúci graf:"
-        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "<p><center><img src=\"graph_legend."+getDotImageExtension()+"\"></center>\n"
         "<p>\n"
         "Bloky (tj. uzly) v uvedenom grafe majú nasledujúci význam:\n"
         "<ul>\n"
@@ -1084,16 +1056,6 @@ class TranslatorSlovak : public Translator
       return "Zoznam testov";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "Metódy DCOP";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1172,7 +1134,7 @@ class TranslatorSlovak : public Translator
     /*! Used as ansicpg for RTF fcharset */
     virtual QCString trRTFCharSet()
     {
-      return "3";
+      return "238";
     }
 
     /*! Used as header RTF general index */
@@ -1404,13 +1366,6 @@ class TranslatorSlovak : public Translator
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the index
-     *  of each page before the search field.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Vyhľadať";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1645,6 +1600,7 @@ class TranslatorSlovak : public Translator
         case ClassDef::Protocol:   result += "protokolu "; break;
         case ClassDef::Category:   result += "kategórie "; break;
         case ClassDef::Exception:  result += "výnimky "; break;
+        default: break;
       }
       result += clName;
       return result;
@@ -1712,6 +1668,7 @@ class TranslatorSlovak : public Translator
         case ClassDef::Protocol:   result+="k tomuto protokolu"; break;
         case ClassDef::Category:   result+="k tejto kategórii"; break;
         case ClassDef::Exception:  result+="k tejto výnimke"; break;
+        default: break;
       }
       result+=" bola vygenerovaná z ";
       if (single) result+="nasledujúceho súboru:";
@@ -1783,12 +1740,6 @@ class TranslatorSlovak : public Translator
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Graf závislosti adresárov pre "+name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
@@ -1958,6 +1909,62 @@ class TranslatorSlovak : public Translator
       return "Návrhová schéma";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.4
+//////////////////////////////////////////////////////////////////////////
+
+    /** old style UNO IDL services: implemented interfaces */
+    virtual QCString trInterfaces()
+    { return "Exportované rozhrania"; }
+
+    /** old style UNO IDL services: inherited services */
+    virtual QCString trServices()
+    { return "Začlenené služby"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroups()
+    { return "Konštantné skupiny"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroupReference(const char *namespaceName)
+    {
+      QCString result="Konštantné skupiny z ";
+      result += namespaceName;
+      return result;
+    }
+    /** UNO IDL service page title */
+    virtual QCString trServiceReference(const char *sName)
+    {
+      QCString result="Popis služby ";
+      result += sName;
+      return result;
+    }
+    /** UNO IDL singleton page title */
+    virtual QCString trSingletonReference(const char *sName)
+    {
+      QCString result="Popis singletonu ";
+      result += sName;
+      return result;
+    }
+    /** UNO IDL service page */
+    virtual QCString trServiceGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result="Dokumentácia k tejto službe bola vygenerovaná ";
+      if (single) result+="z nasledujúceho súboru:";
+      else        result+="z nasledujúcich súborov:";
+      return result;
+    }
+    /** UNO IDL singleton page */
+    virtual QCString trSingletonGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result="Dokumentácia k tomuto singletonu bola vygenerovaná ";
+      if (single) result+="z nasledujúceho súboru:";
+      else        result+="z nasledujúcich súborov:";
+      return result;
+    }
+
 //////////////////////////////////////////////////////////////////////////
 };
 
